package test2.tool;

/**/
import test2.node.Node;
import test2.lexer.Lexer;
import test2.lexer.LexerException;
import test2.parser.Parser;
import test2.parser.ParserException;

import java.io.*;

/**
 * Generic parser utility API, Node builder. This class is not really a
 * builder (in terms of Builder pattern), while the result can be
 * collected directly from it. This builder will parse the input (string, stream) 
 * and create Abstract Syntax Tree, via set of utility methods.
 *@author Mariusz Nowostawski
 */
public class TreeBuilder {

  public static Node getNode(final Reader r)
    throws IOException, LexerException, ParserException {
    return getNode(new PushbackReader(r));
  }
  
  public static Node getNode(final StringBuffer text)
    throws IOException, LexerException, ParserException {
    return getNode(text.toString());
  }

  public synchronized static Node getNode(final String text)
    throws IOException, LexerException, ParserException {
    return getNode(new PushbackReader
      (new BufferedReader
        (new StringReader(text))));
  }
  
  public synchronized static Node getNode(final PushbackReader r)
    throws IOException, LexerException, ParserException {
    Lexer lexer = new Lexer(r);
    Parser parser = new Parser(lexer);
    Node ast = parser.parse();
    return ast;
  }
  
} //TreeBuilder
